@@ -1,32 +1,20 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2019 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef ORG_H
 #define ORG_H
 
 #include "kcontacts_export.h"
+#include <QMap>
 #include <QSharedDataPointer>
 #include <QString>
-#include <QMap>
 
-namespace KContacts {
+namespace KContacts
+{
 /** @short Class that holds a Organization for a contact.
  *  @since 5.3
  */
@@ -34,6 +22,7 @@ class KCONTACTS_EXPORT Org
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Org &);
     friend KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, Org &);
+
 public:
     Org();
     Org(const Org &other);
@@ -57,6 +46,7 @@ public:
     Org &operator=(const Org &other);
 
     Q_REQUIRED_RESULT QString toString() const;
+
 private:
     class Private;
     QSharedDataPointer<Private> d;
